@@ -5,9 +5,8 @@ from netbox.api.serializers import (NetBoxModelSerializer,
                                     WritableNestedSerializer)
 from rest_framework import serializers
 
-from ..models import Contract, Contractor, Invoice, Probe
-
-# Probe
+from ..models import (Component, ComponentService, Contract, Contractor,
+                      Invoice, Probe)
 
 
 class ProbeSerializer(NetBoxModelSerializer):
@@ -53,9 +52,6 @@ class NestedProbeSerializer(WritableNestedSerializer):
         fields = ['id', 'url', 'display', 'name', 'serial', 'time']
 
 
-# Contractor
-
-
 class ContractorSerializer(NetBoxModelSerializer):
     url = serializers.HyperlinkedIdentityField(
         view_name='plugins-api:inventory_monitor-api:contractor-detail'
@@ -86,8 +82,6 @@ class NestedContractorSerializer(WritableNestedSerializer):
         fields = ['id', 'display', 'url', 'name', 'company', 'address']
 
 
-# Contract
-
 class NestedContractSerializer(WritableNestedSerializer):
     url = serializers.HyperlinkedIdentityField(
         view_name='plugins-api:inventory_monitor-api:contract-detail'
@@ -164,3 +158,102 @@ class NestedInvoiceSerializer(WritableNestedSerializer):
     class Meta:
         model = Invoice
         fields = ['id', 'url', 'display', 'name', 'name_internal']
+
+
+class ComponentSerializer(NetBoxModelSerializer):
+    url = serializers.HyperlinkedIdentityField(
+        view_name='plugins-api:inventory_monitor-api:component-detail'
+    )
+    order_contract = NestedContractSerializer()
+
+    class Meta:
+        model = Component
+        fields = [
+            'id',
+            'url',
+            'display',
+            'serial',
+            'serial_actual',
+            'partnumber',
+            'inventory',
+            'project',
+            'vendor',
+            'items',
+            'price',
+            'warranty_start',
+            'warranty_end',
+            'order_contract',
+            'tags',
+            'comments',
+            'custom_fields',
+        ]
+
+
+class NestedComponentSerializer(WritableNestedSerializer):
+    url = serializers.HyperlinkedIdentityField(
+        view_name='plugins-api:inventory_monitor-api:component-detail'
+    )
+    order_contract = NestedContractSerializer()
+
+    class Meta:
+        model = Component
+        fields = [
+            'id',
+            'url',
+            'display',
+            'serial',
+            'serial_actual',
+            'partnumber',
+            'inventory',
+            'items',
+            'price',
+            'order_contract',
+        ]
+
+
+class ComponentServiceSerializer(NetBoxModelSerializer):
+    url = serializers.HyperlinkedIdentityField(
+        view_name='plugins-api:inventory_monitor-api:componentservice-detail'
+    )
+    contract = NestedContractSerializer()
+    component = NestedComponentSerializer()
+
+    class Meta:
+        model = ComponentService
+        fields = [
+            'id',
+            'url',
+            'display',
+            'service_start',
+            'service_end',
+            'service_param',
+            'service_price',
+            'service_category',
+            'service_category_vendor',
+            'component',
+            'contract',
+            'tags',
+            'comments',
+            'custom_fields',
+        ]
+
+
+class NestedComponentServiceSerializer(WritableNestedSerializer):
+    url = serializers.HyperlinkedIdentityField(
+        view_name='plugins-api:inventory_monitor-api:componentservice-detail'
+    )
+    contract = NestedContractSerializer()
+    component = NestedComponentSerializer()
+
+    class Meta:
+        model = ComponentService
+        fields = [
+            'id',
+            'url',
+            'display',
+            'service_start',
+            'service_end',
+            'service_price',
+            'component',
+            'contract',
+        ]
