@@ -1,10 +1,11 @@
-from extras.plugins import PluginTemplateExtension
-from .models import Probe
 from dcim.models import InventoryItem
-from django.db.models import OuterRef, Subquery, Count
+from django.db.models import Count, OuterRef, Subquery
+from extras.plugins import PluginTemplateExtension
 
-#from django.conf import settings
-#plugin_settings = settings.PLUGINS_CONFIG.get('inventory_monitor', {})
+from .models import Probe
+
+# from django.conf import settings
+# plugin_settings = settings.PLUGINS_CONFIG.get('inventory_monitor', {})
 
 
 class DeviceProbeList(PluginTemplateExtension):
@@ -59,19 +60,4 @@ class InventoryItemDuplicates(PluginTemplateExtension):
         )
 
 
-class InvoicesList(PluginTemplateExtension):
-    model = 'inventory_monitor.contract'
-
-    def full_width_page(self):
-        object = self.context['object']
-
-        return self.render(
-            'inventory_monitor/invoices_include.html',
-            extra_context={
-                'object': object,
-                'invoices': object.invoices.all(),
-            }
-        )
-
-
-template_extensions = [DeviceProbeList, InventoryItemDuplicates, InvoicesList]
+template_extensions = [DeviceProbeList, InventoryItemDuplicates]
